.. PyOTI documentation master file, created by
   sphinx-quickstart on Wed Jul 13 11:03:28 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   
========================
 PyOTIC's documentation
========================

PyOTIC is a framework written in Python to

* investigate, analyze and process time-dependent data sets, as they occur in optical tweezers experiments, and
* calibrate optical tweezers by power spectral density analysis.

PyOTIC is shipped with two, mostly independent packages, *pyoti* and *pyotc*.
  

Quick installation
==================

You can install PyOTIC simply by using pip on the command line

.. code-block:: bash
		
		$ pip install pyotc

PyOTIC's objectives
===================

This is coming soon.


PyOTI is written in `Python <http://www.python.org/>`_ 3.4 and
works well with `Jupyter Notebook <http://jupyter.org/>`_.


.. todo::
   write down objectives


User guide
==========

Installation
------------

.. toctree::
   :maxdepth: 1

   install

PyOTI usage
-----------

.. toctree::
   :maxdepth: 1

   pyoti/usage


PyOTC usage
-----------

.. toctree::
   :maxdepth: 1

   pyotc/usage

   
Acknowledgements
----------------
.. todo::
   add acknowledgements

  
License
-------
.. todo::
   add license text


====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
